summaryrefslogtreecommitdiffstats
path: root/gtk-gui.c
diff options
context:
space:
mode:
authorGravatar Linus Torvalds <torvalds@linux-foundation.org>2012-01-17 20:02:33 -0800
committerGravatar Linus Torvalds <torvalds@linux-foundation.org>2012-01-17 20:02:33 -0800
commit6e0ea1ce618d9d28d9512e2afe587bde9ae76fda (patch)
treeda43a9b2a3d3e6cc3c02a080cfeef7717a5b388d /gtk-gui.c
parentd34defc85bdc9872a8d1f1045c524a422e39b39e (diff)
parentdfb94e5470565bc5ad1fd2d0678ef427706bed6c (diff)
downloadsubsurface-6e0ea1ce618d9d28d9512e2afe587bde9ae76fda.tar.gz
Merge branch 'info-split' of git://git.hohndel.org/subsurface
* 'info-split' of git://git.hohndel.org/subsurface: Add statistics for longest, shortest, and shallowest dive Create separate single dive and total stats pages Separate out single dive statistics and total statistics
Diffstat (limited to 'gtk-gui.c')
-rw-r--r--gtk-gui.c22
1 files changed, 12 insertions, 10 deletions
diff --git a/gtk-gui.c b/gtk-gui.c
index e16d60e2d..45185c016 100644
--- a/gtk-gui.c
+++ b/gtk-gui.c
@@ -646,10 +646,8 @@ void init_ui(int *argcp, char ***argvp)
{
GtkWidget *win;
GtkWidget *notebook;
- GtkWidget *dive_info;
+ GtkWidget *nb_page;
GtkWidget *dive_list;
- GtkWidget *equipment;
- GtkWidget *stats;
GtkWidget *menubar;
GtkWidget *vbox;
GdkScreen *screen;
@@ -735,16 +733,20 @@ void init_ui(int *argcp, char ***argvp)
gtk_paned_add2(GTK_PANED(hpane), dive_profile);
/* Frame for extended dive info */
- dive_info = extended_dive_info_widget();
- gtk_notebook_append_page(GTK_NOTEBOOK(notebook), dive_info, gtk_label_new("Dive Notes"));
+ nb_page = extended_dive_info_widget();
+ gtk_notebook_append_page(GTK_NOTEBOOK(notebook), nb_page, gtk_label_new("Dive Notes"));
/* Frame for dive equipment */
- equipment = equipment_widget();
- gtk_notebook_append_page(GTK_NOTEBOOK(notebook), equipment, gtk_label_new("Equipment"));
+ nb_page = equipment_widget();
+ gtk_notebook_append_page(GTK_NOTEBOOK(notebook), nb_page, gtk_label_new("Equipment"));
- /* Frame for dive statistics */
- stats = stats_widget();
- gtk_notebook_append_page(GTK_NOTEBOOK(notebook), stats, gtk_label_new("Info & Stats"));
+ /* Frame for single dive statistics */
+ nb_page = single_stats_widget();
+ gtk_notebook_append_page(GTK_NOTEBOOK(notebook), nb_page, gtk_label_new("Dive Info"));
+
+ /* Frame for total dive statistics */
+ nb_page = total_stats_widget();
+ gtk_notebook_append_page(GTK_NOTEBOOK(notebook), nb_page, gtk_label_new("Overall Stats"));
gtk_widget_set_app_paintable(win, TRUE);
gtk_widget_show_all(win);